from django import forms
from django.utils.translation import ugettext_lazy as _

from django_select2.forms import Select2Widget

from aleksis.core.models import Person

from .models import Book, BookCopy


class BookAddISBNForm(forms.ModelForm):
    class Meta:
        model = Book
        fields = ["isbn"]

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.fields["isbn"].widget.attrs.update({"autofocus": "autofocus"})


class BookGetCopyForm(forms.ModelForm):
    class Meta:
        model = BookCopy
        fields = ["barcode"]

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.fields["barcode"].widget.attrs.update({"autofocus": "autofocus"})


class BookEditForm(forms.ModelForm):
    class Meta:
        model = Book
        fields = ["isbn", "title", "author", "publisher", "year", "edition", "cover"]


class BookCopyEditForm(forms.ModelForm):
    class Meta:
        model = BookCopy
        fields = ["borrower", "borrow_count", "condition", "remarks", "barcode"]

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["borrower"].disabled = True


class BookCopiesBulkAddForm(forms.Form):
    count = forms.IntegerField(label=_("Number of copies"))


class PersonBorrowForm(forms.Form):
    borrower = forms.ModelChoiceField(
        label=_("Person"), queryset=Person.objects.all(), widget=Select2Widget
    )
    barcodes = forms.CharField(label=_("Barcodes"), widget=forms.Textarea)
